/*
 * Copyright (C) 2010-2011 Sebastien Helleu <flashcode@flashtux.org>
 *
 * This file is part of WeeChat, the extensible chat client.
 *
 * WeeChat is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * WeeChat is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * rmodifier-debug.c: debug functions for rmodifier plugin
 */

#include <stdlib.h>
#include <string.h>

#include "../weechat-plugin.h"
#include "rmodifier.h"
#include "rmodifier-debug.h"


/*
 * rmodifier_debug_signal_debug_dump_cb: dump rmodifier data in WeeChat log file
 */

int
rmodifier_debug_signal_debug_dump_cb (void *data, const char *signal,
                                      const char *type_data, void *signal_data)
{
    /* make C compiler happy */
    (void) data;
    (void) signal;
    (void) type_data;
    
    if (!signal_data
        || (weechat_strcasecmp ((char *)signal_data, RMODIFIER_PLUGIN_NAME) == 0))
    {
        weechat_log_printf ("");
        weechat_log_printf ("***** \"%s\" plugin dump *****",
                            weechat_plugin->name);
        
        rmodifier_print_log ();
        
        weechat_log_printf ("");
        weechat_log_printf ("***** End of \"%s\" plugin dump *****",
                            weechat_plugin->name);
    }
    
    return WEECHAT_RC_OK;
}

/*
 * rmodifier_debug_init: initialize debug for rmodifier plugin
 */

void
rmodifier_debug_init ()
{
    weechat_hook_signal ("debug_dump",
                         &rmodifier_debug_signal_debug_dump_cb, NULL);
}
